############
ModelJob API
############

.. _wait_for_async_model_creation-api-label:
.. autofunction:: datarobot.models.modeljob.wait_for_async_model_creation

.. autoclass:: datarobot.models.ModelJob
   :members:
   :inherited-members:
